@@ -7,8 +7,8 @@ var keyMap = {
 	ka : "colorAmbient", // Ambient color: Ka 1.000 1.000 1.000
 	ks : "colorSpecular", // Specular color: Ks 1.000 1.000 1.000
 	ns : "specularCoef", // Specular coefficient: Ns 154.000
-	tr : "transparency", // Transparency: Tr 0.9 or d 0.9
-	d : "transparency", // Transparency: Tr 0.9 or d 0.9
+	tr : "opacity", // Transparency: Tr 0.9 or d 0.9
+	d : "opacity", // Transparency: Tr 0.9 or d 0.9
 	ni : "opticalDensity", // Optical density: Ni 1.0
 	map_kd : "mapDiffuse", // Diffuse texture: map_Kd texture_diffuse.jpg
 	map_ka : "mapAmbient", // Ambient texture: map_Ka texture_ambient.jpg
@@ -88,8 +88,10 @@ function parser( mtl, options ){
 			materials.push(material);
 
 		} else if ( materials.length > 0 ) {
+			// colorAmbient disabled for THREE.js > r80
+			if ( key === "ka" ) continue;
 
-			if ( key === "ka" || key === "kd" || key === "ks" ) {
+			if ( key === "kd" || key === "ks" ) {
 
 				var ss = value.split( delimiter_pattern, 3 );
 				materials[ index ][ keyMap[key] ] = [ parseFloat( ss[0] ), parseFloat( ss[1] ), parseFloat( ss[2] ) ];
